Displays a formatted summary of a foldlist object, showing fold structure and held-out information.
Usage
# S3 method for class 'foldlist'
print(x, ...)Displays a formatted summary of a foldlist object, showing fold structure and held-out information.
# S3 method for class 'foldlist'
print(x, ...)