Skip to contents

Displays a summary of a multiblock object, including the number of blocks, stacking orientation, and dimensions of each block.

Usage

# S3 method for class 'multiblock_list'
print(x, ...)

Arguments

x

A multiblock object

...

Additional arguments passed to print methods

Value

Invisibly returns the input object