Retrieves design information from a hyperdesign object, either for all blocks or for a specific block.
Usage
# S3 method for class 'hyperdesign'
design(x, block, ...)Value
If block is specified, returns design for that block; otherwise returns a list of designs for all blocks
See also
Other hyperdesign functions:
as_multidesign(),
df_to_hyperdesign(),
hyperdesign.list(),
init_transform.hyperdesign(),
subset.hyperdesign(),
xdata.hyperdesign()
Examples
d1 <- multidesign(matrix(rnorm(10*20), 10, 20),
data.frame(y=1:10, condition=rep(c("A","B"), 5)))
d2 <- multidesign(matrix(rnorm(10*20), 10, 20),
data.frame(y=1:10, condition=rep(c("A","B"), 5)))
hd <- hyperdesign(list(d1, d2))
# Get all designs
all_designs <- design(hd)
# Get design for block 1
block1_design <- design(hd, block=1)