Displays a summary of a multiblock object, including the number of blocks, stacking orientation, and dimensions of each block.
Usage
# S3 method for class 'multiblock_list'
print(x, ...)Displays a summary of a multiblock object, including the number of blocks, stacking orientation, and dimensions of each block.
# S3 method for class 'multiblock_list'
print(x, ...)