Returns indices for splitting a multidesign object based on combinations of design variables, without actually splitting the data.
Usage
# S3 method for class 'multidesign'
split_indices(x, ..., collapse = FALSE)Value
A tibble containing:
- group variables
The splitting variables and their values
- indices
List column of indices for each group
- .splitvar
Combined string of grouping values
See also
Other multidesign functions:
multidesign(),
reduce.multidesign(),
split.multidesign(),
subset.multidesign(),
summarize_by.multidesign()
Examples
X <- matrix(rnorm(40*10), 40, 10)
Y <- data.frame(condition = rep(c("A","B"), each=20),
block = rep(1:4, each=10))
mds <- multidesign(X, Y)
idx <- split_indices(mds, condition)